#
# spec file for package pangomm1_4
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver -1_4-1
%define _name   pangomm

Name:           pangomm1_4
Version:        2.46.4
Release:        1.2
Summary:        C++ interface for pango
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.gtkmm.org
Source0:        https://download.gnome.org/sources/pangomm/2.46/%{_name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE pangomm1_4-docs-without-timestamp.patch dimstar@opensuse.org -- Do not add timestamps to generated doc files
Patch0:         pangomm1_4-docs-without-timestamp.patch
BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(cairomm-1.0) >= 1.2.2
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.48.0
BuildRequires:  pkgconfig(pangocairo) >= 1.45.1

%description
pangomm provides a C++ interface to the pango library.

%package -n libpangomm%{so_ver}
Summary:        C++ interface for pango
Group:          System/Libraries

%description -n libpangomm%{so_ver}
pangomm provides a C++ interface to the pango library.

%package devel
Summary:        C++ interface for pango -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libpangomm%{so_ver} = %{version}

%description devel
pangomm provides a C++ interface to the pango library.

%prep
%autosetup -p1 -n %{_name}-%{version}
chmod -x NEWS

%build
%meson \
	-Dbuild-documentation=false \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}/%{prefix}

%check
%meson_test

%post -n libpangomm%{so_ver} -p /sbin/ldconfig
%postun -n libpangomm%{so_ver} -p /sbin/ldconfig

%files -n libpangomm%{so_ver}
%license COPYING
%doc NEWS README.md
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/pangomm-1.4

%changelog
* Wed May 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.46.4:
  + Coverage: Don't use deprecated pango_coverage_ref/unref()
  + Documentation:
  - Doxyfile.in: Don't hide undocumented classes
  - Remove AUTHORS, HACKING, README.SUN; add general info to
    README.md.
  + Meson build:
  - Detect if we build from a git subtree
  - Don't copy files with configure_file()
  - Fix the evaluation of is_git_build on Windows
  - Don't fail if warning_level=everything
- Enable check section: run meson test (no tests defined as of
  now).
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.3:
  + Context::get_font_map(): Fix reference count.
  + Build:
  - Require Meson >= 0.55.0
  - Meson build:
    . Specify 'check' option in run_command(). Will be necessary
    with future versions of Meson.
    . Check if Perl is required for building documentation.
    . Avoid unnecessary configuration warnings.
    . Re-organize warning-related compiler flags for MSVC.
* Mon Dec 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Switch back to released tarballs: Stop passing
  maintainer-mode=true to meson and remove m4, mm-common and
  perl(XML::Parser) BuildRequires, as this was all only needed to
  build a git-checkout.
* Sun Dec  5 2021 bjorn.lie@gmail.com
- Update to version 2.46.2:
  * Move to stable released tag, no code changes.
* Wed Dec  1 2021 bjorn.lie@gmail.com
- Update to version 2.46.1+7:
  * NMake Makefiles: Fix header installation
  * NMake Makefiles: Correct VS2019 toolset number
  * build: Support Visual Studio 2022 builds
  * docs/reference/Doxyfile.in: Remove obsolete entry
  * Don't include individual pango headers, part 2
  * Don't include individual pango headers
  * Use pango from the main branch
  * 2.46.1
  * Documentation: Let links point to pangomm-1.4 versions
  * Add dependencies to Doxygen tag files in subprojects
- Switch to using a gitcheckout via source service. Pass
  maintainer-mode=true to meson and add m4, mm-common and
  perl(XML::Parser) BuildRequires, as this is needed with a
  git-checkout.
* Thu Oct  7 2021 pgajdos@suse.com
- turn off doc build, it does not work with new doxygen
* Tue Sep 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add pangomm1_4-docs-without-timestamp.patch: do not add
  timestampt to generated doc files.
* Tue Sep 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.46.1:
  + Meson build:
  - Make it possible to use pangomm as a subproject.
  - No implicit_include_directories.
  - Use relative paths to untracked/.
  + pangommconfig.h.*: Don't dllimport on MinGW.
* Wed Jan 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.0:
  + Attribute: Add Overline and ShowFlags enums and some create*()
    methods.
  + Font, FontFace, FontFamily, FontMetrics: Add new methods.
  + LayoutIter: Fix get_run().
  + LayoutRun:
  - Fix a memory leak in split().
  - Make most methods public.
  + GlyphString, Item: Wrap pango_shape_with_flags().
  + Layout:
  - Add set/get_line_spacing().
  - Add get_const_line() and get_const_lines().
  + Coverage: Deprecate create(bytes, n_bytes), max(), to_bytes().
  + Build: Requires pango >= 1.45.1 because of Overline.
* Fri Dec 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.42.2:
  + Build:
  - Use __declspec(dllexport) when building with Visual Studio
  - Meson build: Avoid some recompilations
  - Meson build: Better error message if trying to build with
    maintainer-mode=false when true is necessary
  - Meson build: Set default value of the 'warnings' option to
    'min'
  - Improve NMake support
  - Improve Visual Studio support
  - docs/reference/: Update for Doxygen >= 1.8.16
  - Meson build: Fix versioning on macOS
- Add meson BuildRequires and macros following upstreams port.
- Add doxygen, graphviz and xsltproc  BuildRequires, needed now for
  building documentation.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Tweak setup macro and fdupes call.
* Sat Mar 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.42.1:
  + Coverage: Ignore deprecations of pango functions (so it can be
    used with the latest versions of pango).
  + Layout::get_lines(): Fix ownership of the GSList.
  + pango/src/color.hg: Fix call to _CLASS_BOXEDTYPE_STATIC.
  + Build:
  - tools/gen_scripts: Update for non-source-dir builds.
  - Add support for building pangomm with Meson.
  - meson.build: Check if .git is a directory or file.
  - NMake Makefiles: Allow builds from a GIT checkout.
  - The fixed call to _CLASS_BOXEDTYPE_STATIC in color.hg is
    necessary in order to use glibmm 2.64.0 or later, combined
    with maintainer-mode in pangomm.
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 2.42.0:
  + Attribute: Add several create_attr_*() methods.
  + FontDescription: Add set/get_variations().
- Changes from version 2.40.2:
  + Build: Replace the Visual Studio project files with MSVC NMake
    project files.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec  5 2016 jengelh@inai.de
- Rectify RPM groups and replace old macros.
* Fri Dec  2 2016 dimstar@opensuse.org
- Rename to pangomm1_4 (1.4 referecing the ABI/API version). Legacy
  package to stay around, while pangomm gets a new ABI/API.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 2.40.1:
  + C++11: Make all operator bool()s explicit.
  + Build: Fix silent builds (bgo#768797).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Mar 29 2016 zaitor@opensuse.org
- Update to version 2.40.0:
  + No major changes compared to 2.39.1.
* Mon Nov 30 2015 zaitor@opensuse.org
- Update to version 2.39.1:
  + Renderer: Added get/set_alpha().
  + Attribute: Added create_attr_background_alpha() and
    create_attr_foreground_alpha().
  + Reduce the cairomm dependency back to 1.2.2 (bgo#755460).
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.38.1:
  + Regenerate with the latest glibmm.
- Changes from version 2.38.0:
  + MSVC build fixes.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.37.2:
  + Rebuilt with latest glibmm, whose gmmproc generates C++ move
    operations.
  + C++11: Mark all _CLASS_OPAQUE_REFCOUNTED classes as final.
* Sat Jul 18 2015 zaitor@opensuse.org
- Update to version 2.37.1:
  + Use (and require) C++11.
  + Attribute: fix operator!= (bgo#751531).
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 2.36.0:
  + No changes compared to 2.35.1.
* Wed Feb  4 2015 dimstar@opensuse.org
- Update to version 2.35.1:
  + Context: Add get_serial().
  + FontMap: Add get_serial().
  + Layout: Add get_character_count() and get_serial().
  + Documentatoin: Update appearance to match recent glibmm and
    gtkmm.
  + Win32 MSVC 2008/2010 Build: Many updates and corrections.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 2.34.0:
  + Remove the use of g_type_init() because it has been deprecated.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.28.4:
  + Add #includes needed with the latest glibmm.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 2.28.3:
  + Build
  - Ship convert_pangomm.m4 in tarballs (bgo#657817).
  - Don't use obsolete macros.
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 2.28.2:
  + bgo#645669: Install the m4 files even without
  - -enable-maintainer-mode, as with other modules.
- Use source services: download_url and set_version.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.28.1:
  + Avoid a tarball dependency on mm-common.
- Changes from version 2.28.0:
  + regenerated tarball due to changes in an m4 macro in mm-common.
* Wed Feb 23 2011 adam@mizerski.pl
- Update to version 2.27.1:
  + LayoutIter: This now has a copy constructor.
  + Layout::get_iter(): There is now a version of this method that
    returns a LayoutIter. The version with the output parameter is
    now deprecated.
- Remove libsigc++2-devel and update-desktop-files BuildRequires.
- Change BuildRequires to pkgconfig() ones:
  + old ones: cairomm-devel, glibmm2-devel, pango-devel.
  + pkgconfig() ones: cairomm-1.0, glibmm-2.4, pangocairo.
- Remove explicit Requires for glibmm2-devel, cairomm-devel,
  atk-devel and pango-devel in devel subpackage: they will
  automatically be added the pkgconfig() way.
- Remove Requires for devel subpackage in doc subpackage: it's not
  really needed.
- Pass --disable-static to configure.
* Thu Dec  9 2010 vuntz@opensuse.org
- Update to version 2.26.3:
  + Build/Installer: Added support for MSVC 2010 and 64 bit.
* Thu Jun 10 2010 wittemar@googlemail.com
- build 32bit-package
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.26.2:
  + Documentation: Added main page text at index.html.
- Changes from version +2.26.1:
  + Minor documentation improvements.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.26.0:
  + Minor documentation build fixes.
* Fri Aug 28 2009 vuntz@novell.com
- Update to version 2.25.1.3:
  + Change public documentation location to library.gnome.org in
    the pkg-config files as well.
- Changes from version 2.25.1.2:
  + Change public documentation location to library.gnome.org.
- Changes from version 2.25.1.1:
  + Reenable the per-class hierarchy graphs in the reference
    documentation.
  + Drop the custom HTML header and footer, and use the shared
    doxygen.css file from mm-common.
* Wed Aug 26 2009 dimstar@opensuse.org
- Update to version 2.25.1:
  + Reworked the build system, using mm-common.
* Thu Mar 26 2009 vuntz@novell.com
- Remove BuildRequires on devhelp: it's only needed for directory
  ownership, and we can own the directories anyway.
* Tue Mar 10 2009 vuntz@novell.com
- Update to version 2.24.0:
  + Layout: Added show_in_cairo_context(). bgo#560232.
  + Build: Allow pangomm to build outside the source tree.
    bgo#570322
  + License Header consistency.
* Mon Dec  8 2008 mboman@suse.de
- Update to version 2.14.1:
  + Windows build: Use the new DLL naming convention, like boost.
  + Corrected the index page for DevHelp (bgo#559896)
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.14.0:
  + Language: Added get_scripts().
  + README and COPYING fixes.
  + Fixed the Windows build with Visual Studio Express
* Thu Sep 18 2008 maw@suse.de
- Update to version 2.13.8:
  + Context: Added set_font_map() because the C function is now
    public (non backend-only) API
  + LayoutRun/GlyphItem: Added split() and letter()
  + Renderer: Added draw_glyph_item()
  + CairoFontMap:: Added set_default().
* Thu Sep 18 2008 maw@suse.de
- Initial import of version 2.13.7.
